## Examples

Here you can find a list of practical examples on how you can use ZenML with brief descriptions for each example:

- **quickstart**: The official quickstart tutorial.

In order to quickly run any of these examples, use the ZenML CLI:

```bash
# install CLI
pip install zenml

# initialize CLI
git init
zenml init

# pull example
zenml examples pull EXAMPLE_NAME
cd zenml_examples/EXAMPLE_NAME
```

Have any questions? Want more tutorials? Spot out-dated, frustrating tutorials? We got you covered!

Feel free to let us know by creating an 
[issue](https://github.com/zenml-io/zenml/issues) here on our Github or by reaching out to us on our 
[Slack](https://zenml.io/slack-invite/). 